.htaccess
CHANGELOG.txt
FA.pem
README.md
SECURITY.md
access
admin
applications
company
config.default.php
dimensions
doc
fixed_assets
frontaccounting.php
gl
includes
index.php
install
inventory
js
lang
manufacturing
modules
purchasing
reporting
sales
sql
taxes
themes
tmp
version.php
config.php
config_db.php
installed_extensions.php