.babelrc
.bowerrc
.buildpath
.codecov.yml
.dockerignore
.editorconfig
.env
.env.example
.env.testing
.htaccess
.travis.yml
404.html
ABOUT.md
CHANGELOG.md
CONTRIBUTING.md
Dockerfile
Jenkinsfile
LICENSE
README.md
SECURITY.md
UPGRADING.md
Web.config
app
artisan
bootstrap
composer.json
composer.lock
config
crowdin.yml
database
docker-compose.yml
favicon.ico
gulpfile.js
index.php
monorepo-builder.yaml
package-lock.json
package.json
phpunit-coverage.xml
phpunit.dusk.xml
phpunit.xml
postcss.config.js
public
resources
routes
server.php
src
storage
tests
userfiles
vendor
version.txt
vite.config.js
xdebug_server.php