.htaccess
.user.ini
3rdparty
AUTHORS
COPYING
LICENSES
REUSE.toml
apps
composer.json
composer.lock
config
console.php
core
cron.php
dist
index.html
index.php
lib
occ
ocs
ocs-provider
package-lock.json
package.json
public.php
remote.php
resources
robots.txt
status.php
themes
updater
version.php