.htaccess
CHANGELOG.md
INSTALL
LICENSE
README.md
SECURITY.md
SQL
UPGRADING
bin
composer.json
composer.json-dist
composer.lock
config
index.php
installer
logs
plugins
program
public_html
skins
temp
vendor