.dockerignore
.editorconfig
.env
.gitignore
.htaccess
CHANGELOG.md
Dockerfile
LICENSE.md
README.md
UPGRADE_3.6.md
UPGRADE_3.7.md
UPGRADE_3.8.md
UPGRADE_3.9.md
UPGRADE_4.0.md
UPGRADE_5.0.md
VERSION.md
app
apple-touch-icon.png
autoload.php
bin
composer.json
composer.lock
css
docker-compose.yml
favicon.ico
fonts
gulpfile.js
index.php
js
package.json
phpstan.neon
phpunit.xml.dist
robots.txt
src
tests
tile.png
var
vendor
yarn.lock