.eslintrc.cjs
.github
.husky
.php-cs-fixer.php
.prettierignore
.scrutinizer.yml
README.md
SECURITY.md
api
cache
classes
config.TEMPLATE.inc.php
config.inc.php
controllers
cypress.config.js
cypress.travis.env.json
dbscripts
docs
favicon.ico
index.php
jobs
js
jsconfig.json
lib
locale
pages
phpdoc.dist.xml
plugins
public
registry
robots.txt
schemas
schemaspy.properties
styles
templates
tools
vite.config.frontend.js
vite.config.js