.gitignore
AUTHOR.txt
CHANGES.txt
CONTRIBUTING.md
CONTRIBUTORS.md
COPYRIGHT.txt
ChangeLog.txt
LICENSE.md
README.md
SECURITY.md
SUPPORT.txt
TESTS.md
UPGRADE.txt
actions
classes
components
configurations
index.php
installation
libraries
licenses
locale
opensource-socialnetwork.xml
robots.txt
system
themes
upgrade
vendors
.htaccess
.user.ini
cache